library pgraph;
graphset;

/*
thr_CES1.PRG
Performs empirical work reported in
"The Solow Model with CES" (main text)

Written by
Bruce E. Hansen
Department of Economics
University of Wisconsin
bhansen@ssc.wisc.edu

Modified by 
Winford Masanjala and
Chris Papageorgiou
Department of Economics
Louisiana State Univeristy
cpapa@lsu.edu

*/

@  Load procedures and data                  @

#include thr_est.prc;
#include thr_het.prc;
load data= dur_john;
@  Exclude missing variables and oil states  @

data = selif(data,1-(data[.,5].== -999));
data = selif(data,1-(data[.,6].== -999));
data = selif(data,1-(data[.,10].== -999));
data = selif(data,1-(data[.,11].== -999));
data = selif(data,data[.,2]);
data(rows);
data(cols);
@  Make data transformations                 @

diff=ln(data[.,6])-ln(data[.,5]);
q = data[.,5];
gdp60=ln(q);
iony=ln(data[.,9]/100);
pgro=ln(data[.,8]/100+.05);
sch=ln((data[.,10])/100);
sk=iony-pgro;
sh=sch-pgro;
sk2=sk^2;
sh2=sh^2;
skh2=(sh-sk)^2;
lit = data[.,11];
dat=diff~gdp60~iony~pgro~sch~q~lit~sk~sh~sk2~sh2~skh2;

@  Program switches                          @

rep = 1000;
h   = 1;
na  = { GNP_Gwth, GDP_1960, Inv/GDP, Pop_Gwth, School, GDP_1960, Literacy, Inv/n, Sch/n, Inv2, Sch2, Invsch2 };
@dum=2|3|4|5;@
dum=2|3|4|5|10|11|12;
@dum=2|8|9;@
@dum = 2|8|9|10|11|12;@
output file=growth.out reset;


"Testing for a First Sample Split, Using Output";
"";
{f_test,p_value}=thr_het(dat,1,dum,6,0.15,1000);
"";"";
"Testing for a First Sample Split, Using Literacy Rate";
"";
{f_test,p_value}=thr_het(dat,1,dum,7,0.15,1000);
"";"";

@  Estimate First Sample Split, Using Output as Threshold @

qhat1 = thr_est(dat,na,1,dum,6,h);
qhat2 = thr_est(dat,na,1,dum,7,h);

@  Second Level a@

i = (q .> qhat1);
dati = selif(dat,i);
dati(rows);
"Sub-Sample, Incomes over 777";
"Testing for a Second Sample Split, Using Output";
"";
{f_test,p_value}=thr_het(dati,1,dum,6,0.15,1000);
"";"";
"Testing for a Second Sample Split, Using Literacy Rate";
"";
{f_test,p_value}=thr_het(dati,1,dum,7,0.15,1000);
"";"";

@  Estimate Second Sample Split, Using Literacy as Threshold @

qhat3 = thr_est(dati,na,1,dum,7,h);
qhat4 = thr_est(dati,na,1,dum,6,h);

@  Third Level @

i1 = (lit.<= qhat3).*i;
i2 = (lit.>  qhat3).*i;
dat1 = selif(dat,i1);
dat2 = selif(dat,i2);
dat1(rows);
dat2(rows);
"Sub-Sample, Incomes over 777, Literacy Under 22";
"Testing for a Third Sample Split, Using Output";
"";
{f_test,p_value}=thr_het(dat1,1,dum,6,0.15,1000);
"";"";
"Testing for a Third Sample Split, Using Literacy Rate";
"";
{f_test,p_value}=thr_het(dat1,1,dum,7,0.15,1000);
"";"";
"Sub-Sample, Incomes over 777, Literacy Over 22";
"Testing for a Third Sample Split, Using Output";
"";
{f_test,p_value}=thr_het(dat2,1,dum,6,0.15,1000);
"";"";
"Testing for a Third Sample Split, Using Literacy Rate";
"";
{f_test,p_value}=thr_het(dat2,1,dum,7,0.15,1000);
"";"";

qhat5 = thr_est(dat2,na,1,dum,6,h);
qhat6 = thr_est(dat2,na,1,dum,7,h);

stop;
@Fourth Level@

ii1 = (q.<= qhat5).*i2;
ii2 = (q.>  qhat5).*i2;
dat3 = selif(dat,ii1);
dat4 = selif(dat,ii2);
dat3(rows);
dat4(rows);
"Sub-Sample, Incomes over 777, Literacy Over 22 and Incomes under 4802";
"Testing for a Third Sample Split, Using Output";
"";
{f_test,p_value}=thr_het(dat3,1,dum,6,0.15,1000);
"";"";
"Testing for a Third Sample Split, Using Literacy Rate";
"";
{f_test,p_value}=thr_het(dat3,1,dum,7,0.15,1000);
"";"";
"Sub-Sample, Incomes over 777, Literacy Over 22 and Incomes over 4802";
"Testing for a Third Sample Split, Using Output";
"";
{f_test,p_value}=thr_het(dat4,1,dum,6,0.15,1000);
"";"";
"Testing for a Third Sample Split, Using Literacy Rate";
"";
{f_test,p_value}=thr_het(dat4,1,dum,7,0.15,1000);
"";"";
end;
@qhat4 = thr_est(dat3,na,1,dum,7,h);
qhat5 = thr_est(dat3,na,1,dum,6,h);@



output off;

